.. image:: logo/BBP-NeuroTS.jpg

.. mdinclude:: ../../README.md
    :start-line: 2


.. toctree::
   :hidden:
   :maxdepth: 2

   Home <self>
   params_and_distrs
   examples/index
   api
   changelog
   contributing
